---
hide:
  - navigation
  - toc
---

<!-- Copyright: © 2024 Jonathan Fox
License: GNU AGPL, version 3 or later; http://www.gnu.org/licenses/agpl.html
Full source code: https://github.com/jonathanfox5/gogadget -->

## Where to ask questions

Firstly, please see if your issue is addressed in [Getting Started](../getting_started/getting_started.md), the [video tutorial](../getting_started/video_tutorial.md) or, if you are comfortable with it, the [Detailed Command Reference](../reference/command_reference.md).

If you can't find the answer, you can ask on GitHub:

- The [issues page](https://github.com/jonathanfox5/gogadget/issues) can be used for bug reports and feature requests.
- The [discussions page](https://github.com/jonathanfox5/gogadget/discussions) can be used for any other purpose (e.g. questions on how to do specific things within the tool).

I will do my best to provide support in a timely manner. However, I run this project in my spare time so any troubleshooting that you can do yourself first goes a long way!

## A different type of language learning "get help"?

As a language learner, there is a very, very small (but real) chance that you were looking for this instead...

<div class = "iframe-responsive-container">
<iframe class = "iframe-responsive-content" src="https://www.youtube.com/embed/r78zVjtPgYQ" frameBorder="0"></iframe>
</div>
